sensitivity_score — imbalanced-ensemble 0.1.0 documentation

# sensitivity_score

`imbalanced_ensemble.metrics.` `sensitivity_score`(y_true, y_pred, *, labels=None, pos_label=1, average='binary', sample_weight=None)

  Compute the sensitivity

  The sensitivity is the ratio `tp / (tp + fn)` where `tp` is the number of true positives and `fn` the number of false negatives. The sensitivity quantifies the ability to avoid false negatives.

  The best value is 1 and the worst value is 0.

  Read more in the User Guide.

  Parameters
    y_truendarray of shape (n_samples,)

      Ground truth (correct) target values.

    y_predndarray of shape (n_samples,)

      Estimated targets as returned by a classifier.

    labelslist, default=None

      The set of labels to include when `average != 'binary'`, and their order if `average is None`. Labels present in the data can be excluded, for example to calculate a multiclass average ignoring a majority negative class, while labels not present in the data will result in 0 components in a macro average.

    pos_labelstr or int, default=1

      The class to report if `average='binary'` and the data is binary. If the data are multiclass, this will be ignored; setting `labels=[pos_label]` and `average != 'binary'` will report scores for that label only.

    averagestr, default=None

      If `None`, the scores for each class are returned. Otherwise, this determines the type of averaging performed on the data:

      `'binary'`:

        Only report results for the class specified by `pos_label`. This is applicable only if targets (`y_{true,pred}`) are binary.

      `'micro'`:

        Calculate metrics globally by counting the total true positives, false negatives and false positives.

      `'macro'`:

        Calculate metrics for each label, and find their unweighted mean. This does not take label imbalance into account.

      `'weighted'`:

        Calculate metrics for each label, and find their average, weighted by support (the number of true instances for each label). This alters ‘macro’ to account for label imbalance; it can result in an F-score that is not between precision and recall.

      `'samples'`:

        Calculate metrics for each instance, and find their average (only meaningful for multilabel classification where this differs from `accuracy_score()`).

    sample_weightndarray of shape (n_samples,), default=None

      Sample weights.

  Returns
    specificityfloat (if average is None) or ndarray of shape (n_unique_labels,)

      The specifcity metric.

  Examples

      >>> import numpy as np
      >>> from imbalanced_ensemble.metrics import sensitivity_score
      >>> y_true = [0, 1, 2, 0, 1, 2]
      >>> y_pred = [0, 2, 1, 0, 0, 1]
      >>> sensitivity_score(y_true, y_pred, average='macro')
      0.33333333333333331
      >>> sensitivity_score(y_true, y_pred, average='micro')
      0.33333333333333331
      >>> sensitivity_score(y_true, y_pred, average='weighted')
      0.33333333333333331
      >>> sensitivity_score(y_true, y_pred, average=None)
      array([ 1.,  0.,  0.])